==> pigsty-v1.2.0.tgz: pigsty/docs/zh-cn/_sidebar.md <==
- 上手
  - [上手指南](s-intro.md)
  - [安装部署](s-install.md)
  - [本地沙箱](s-sandbox.md)
  - [用户界面](s-interface.md)
  - [常见问题](s-faq.md)

- 概念
  - [架构](c-arch.md)
  - [实体](c-entity.md)
  - [配置](c-config.md)
  - [服务](c-service.md)
  - [数据库](c-database.md)
  - [用户](c-user.md)
  - [权限](c-privilege.md)
  - [认证](c-auth.md)
  - [接入](c-access.md)  
  
- 教程
  - [部署](t-deploy.md)
  - [准备](t-prepare.md)
  - [常用操作命令](t-operation.md)
  - [使用与制作离线安装包](t-offline.md)  
  - [仅监控系统部署](t-monly.md)
  - [升级Grafana后端数据库](t-grafana-upgrade.md)
  - [配置Prometheus远程存储](t-promscale.md)
  - [使用CMDB替换静态配置](t-cmdb.md)
  - [部署日志收集服务](t-logging.md)
  - [分析CSV日志样本](t-log-analysis.md)  
  - [使用Jupyter进行数据分析](t-jupyter.md) 
  - [定制Patroni配置模板](t-patroni-template.md)
  - [深度定制数据库模板](t-customize-template.md)
  - [安装Pigsty扩展应用](t-application.md)
  - [数据库备份与恢复](t-backup.md)  
  - [腾讯云虚拟机部署案例](t-vpc-deploy.md)
  - [数据库迁移](t-migration.md)


- 监控
  - [监控面板](m-dashboard.md)
  - [服务发现](m-discovery.md)
  - [监控指标](m-metric.md)
  - [告警系统](m-alert.md)

- 配置
  - [配置总览](v-config.md)
  - [连接参数](v-connect.md)
  - [本地仓库](v-repo.md)
  - [节点供给](v-node.md)
  - [基础设施](v-meta.md)
  - [元数据库](v-dcs.md)
  - [数据库安装](v-pg-install.md)
  - [数据库部署](v-pg-provision.md)
  - [数据库定制](v-pg-template.md)
  - [监控系统](v-monitor.md)
  - [服务接入](v-service.md)

- 部署
  - [剧本：基础设施初始化](p-infra.md)
  - [剧本：数据库初始化](p-pgsql.md)
  - [剧本：业务用户创建](p-pgsql-createuser.md)  
  - [剧本：业务数据库创建](p-pgsql-createdb.md)
  - [剧本：数据库下线](p-pgsql-remove.md)
  
- 参考
  - [报警规则](r-alert.md)
  - [文件目录结构](r-fhs.md)

- [社区交流](community.md)
- [路线规划](../roadmap.md)
- [开发日志](devlog)

==> pigsty-v1.3.0.tgz: pigsty/docs/zh-cn/_sidebar.md <==
- 上手
  - [上手指南](s-intro.md)
  - [安装部署](s-install.md)
  - [本地沙箱](s-sandbox.md)
  - [用户界面](s-interface.md)
  - [常见问题](s-faq.md)

- 概念
  - [架构](c-arch.md)
  - [实体](c-entity.md)
  - [配置](c-config.md)
  - [服务](c-service.md)
  - [数据库](c-database.md)
  - [用户](c-user.md)
  - [权限](c-privilege.md)
  - [认证](c-auth.md)
  - [接入](c-access.md)  
  
- 教程
  - [部署](t-deploy.md)
  - [准备](t-prepare.md)
  - [监控系统部署](t-monly.md)
  - [常用操作命令](t-operation.md)
  - [使用与制作离线安装包](t-offline.md)
  - [升级Grafana后端数据库](t-grafana-upgrade.md)
  - [配置Prometheus远程存储](t-promscale.md)
  - [使用CMDB替换静态配置](t-cmdb.md)
  - [部署日志收集服务](t-logging.md)
  - [分析CSV日志样本](t-log-analysis.md)  
  - [使用Jupyter进行数据分析](t-jupyter.md) 
  - [定制Patroni配置模板](t-patroni-template.md)
  - [深度定制数据库模板](t-customize-template.md)
  - [安装Pigsty扩展应用](t-application.md)
  - [数据库备份与恢复](t-backup.md)  
  - [腾讯云虚拟机部署案例](t-vpc-deploy.md)
  - [数据库迁移](t-migration.md)
  - [Redis集群部署与监控](t-redis.md)

- 监控
  - [监控面板](m-dashboard.md)
  - [服务发现](m-discovery.md)
  - [监控指标](m-metric.md)
  - [告警系统](m-alert.md)

- 配置
  - [配置总览](v-config.md)
  - [连接参数](v-connect.md)
  - [本地仓库](v-repo.md)
  - [节点供给](v-node.md)
  - [基础设施](v-meta.md)
  - [元数据库](v-dcs.md)
  - [数据库安装](v-pg-install.md)
  - [数据库部署](v-pg-provision.md)
  - [数据库定制](v-pg-template.md)
  - [监控系统](v-monitor.md)
  - [服务接入](v-service.md)
  - [Redis](v-redis.md)

- 部署
  - [剧本：基础设施初始化](p-infra.md)
  - [剧本：数据库初始化](p-pgsql.md)
  - [剧本：业务用户创建](p-pgsql-createuser.md)  
  - [剧本：业务数据库创建](p-pgsql-createdb.md)
  - [剧本：数据库下线](p-pgsql-remove.md)
  
- 参考
  - [报警规则](r-alert.md)
  - [文件目录结构](r-fhs.md)

- [社区交流](community.md)
- [路线规划](../roadmap.md)
- [开发日志](devlog)
